@@ -34,7 +34,7 @@ class Utils(Object):
 		if not isinstance(old, (dict, Dictionary)):
 			raise dev0s.exceptions.InvalidUsage(f"<website.utils.template>: Parameter [old] requires to be a [dict, Dictionary] not [{new.__class__.__name__}] ({new}).")
 		if new != old:
-			new = Dictionary(old) + Dictionary(new)
+			new = Dictionary(old) + new
 		if isinstance(new, (Dictionary)): new = new.dictionary
 		if safe:
 			return self.serialize_template(new)
